# Generated by Django 2.2.1 on 2020-01-02 16:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('lavender', '0006_blank_packages'),
    ]

    operations = [
        migrations.RenameField(
            model_name='gamelog',
            old_name='log_type',
            new_name='kind',
        ),
        migrations.RemoveField(
            model_name='gamelog',
            name='url',
        ),
        migrations.AddField(
            model_name='gamelog',
            name='payload',
            field=models.TextField(default=''),
        ),
    ]
