# Generated by Django 2.2.1 on 2019-12-14 18:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('lavender', '0005_wardrobe'),
    ]

    operations = [
        migrations.AlterField(
            model_name='player',
            name='packages',
            field=models.ManyToManyField(blank=True, to='lavender.Package'),
        ),
    ]
