# Generated by Django 2.2.1 on 2020-01-07 12:11

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('lavender', '0007_fix_gamelog'),
    ]

    operations = [
        migrations.AlterField(
            model_name='token',
            name='player',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]
