# Generated by Django 2.2.1 on 2019-06-25 18:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('lavender', '0002_add_token_uuid_and_server_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='token',
            name='server_id',
            field=models.CharField(max_length=48, null=True),
        ),
    ]
