# Generated by Django 2.2.1 on 2019-12-08 23:40

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('lavender', '0003_increase_server_id_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='Quenta',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField()),
                ('comments', models.TextField(blank=True)),
                ('approved', models.BooleanField(default=False)),
                ('player', models.OneToOneField(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
