# Generated by Django 2.2.1 on 2019-12-09 00:47

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import functools
import lavender.texture


class Migration(migrations.Migration):

    dependencies = [
        ('lavender', '0004_quenta'),
    ]

    operations = [
        migrations.CreateModel(
            name='Wardrobe',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('skin_height', models.PositiveIntegerField(null=True)),
                ('skin_width', models.PositiveIntegerField(null=True)),
                ('skin', models.ImageField(blank=True, height_field='skin_height', null=True, storage=lavender.texture.OverwriteStorage(), upload_to=functools.partial(lavender.texture.path_handler, *(lavender.texture.TextureType('skin'),), **{}), width_field='skin_width')),
                ('cloak_height', models.PositiveIntegerField(null=True)),
                ('cloak_width', models.PositiveIntegerField(null=True)),
                ('cloak', models.ImageField(blank=True, height_field='cloak_height', null=True, storage=lavender.texture.OverwriteStorage(), upload_to=functools.partial(lavender.texture.path_handler, *(lavender.texture.TextureType('cloak'),), **{}), width_field='cloak_width')),
                ('elytra_height', models.PositiveIntegerField(null=True)),
                ('elytra_width', models.PositiveIntegerField(null=True)),
                ('elytra', models.ImageField(blank=True, height_field='elytra_height', null=True, storage=lavender.texture.OverwriteStorage(), upload_to=functools.partial(lavender.texture.path_handler, *(lavender.texture.TextureType('elytra'),), **{}), width_field='elytra_width')),
                ('player', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
